@@ -5,6 +5,9 @@ use warnings;
 use Data::Dumper;
 use Geo::Coder::Bing;
 
+unless ($ENV{BING_MAPS_KEY}) {
+    die "BING_MAPS_KEY environment variable must be set";
+}
 my $location = join(' ', @ARGV) || die "Usage: $0 \$location_string";
 
 # Custom useragent identifier.
@@ -18,7 +21,11 @@ if (eval "use Compress::Zlib") {
 # Load any proxy settings from environment variables.
 $ua->env_proxy;
 
-my $geocoder = Geo::Coder::Bing->new(ua => $ua);
+my $geocoder = Geo::Coder::Bing->new(
+    key   => $ENV{BING_MAPS_KEY},
+    ua    => $ua,
+    debug => 1,
+);
 my $result = $geocoder->geocode(location => $location);
 
 local $Data::Dumper::Indent = 1;
